module Hyrax
  class ManageBrandingInfoUsingS3
    def initialize(uploaded_file_id, collection_id)
      @collection = Hyrax.config.collection_class.find(collection_id)
      @uploaded_file =  UploadedFile.find_by(id: uploaded_file_id)
      @filename =  @uploaded_file.file.path.split('/').last
    end

    def create_branding_info(role, alt_txt, link_url)
      logo_info = CollectionBrandingInfo.new(
        collection_id: @collection.id,
        filename: @filename,
        role: role,
        alt_txt: alt_txt,
        target_url: link_url
      )
      file = URI.open(refrenced_s3_file_url)

      if file.is_a?(StringIO)
        tmp_file = Tempfile.new
        tmp_file.binmode
        IO.copy_stream(file, tmp_file)
        tmp_file.rewind
        file = tmp_file
      end

      storage.upload(resource: Hyrax::PcdmCollection.new(id: @collection.id),
                      file: file,
                      original_filename: File.join(role, @filename))
      logo_info.local_path = find_local_filename(role)
      logo_info.save(nil, true, true)
      logo_info
    end

    private

    def refrenced_s3_file_url
      s3 = S3StorageService.new
      s3.init_client
    
      s3.presigned_url_for_download(@uploaded_file.file.aws_bucket, @uploaded_file.file.path)
    end

    def find_local_filename(role)
      local_dir = find_local_dir_name(role)
      File.join(local_dir, @filename)
    end
  
    def find_local_dir_name(role)
      File.join(Hyrax.config.branding_path, @collection.id.to_s, role.to_s)
    end

    def storage
      Hyrax.config.branding_storage_adapter
    end

  end
end